@@ -52,7 +52,7 @@ class RSA(object):
 		#
 			
 	# key management.
-	def generate_keys(self):
+	def generate_keys(self, log_level=0):
 
 		# default response.
 		response = utils.__default_response__()
@@ -64,9 +64,12 @@ class RSA(object):
 
 		# checks.
 		if not self.memory:
+			if log_level >= 0: loader = system.console.Loader(f"Generating key {self.directory}")
 			if os.path.exists(directory): 
 				response["error"] = f"Key [{directory}] already exists."
 				return response
+		else:
+			if log_level >= 0: loader = system.console.Loader("Generating key")
 			
 		# generate.
 		key_pair = _RSA_.generate(4096, e=65537)
@@ -88,6 +91,7 @@ class RSA(object):
 			utils.__set_file_path_permission__(public_key_path, permission=644)
 			
 		# response.
+		loader.stop()
 		return r3sponse.success_response(f"Successfully generated key {directory}.", {
 			"private_key":private_key_pem.decode(),
 			"public_key":public_key_pem.decode(),
